# Changelog
All notable changes to this project will be documented (for humans) in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.0.3] - 2017-12-19
A minor release to demonstrate `retrace` functionality

---

Just a template for future records:

## [Unreleased] - Date
TODO Summary
### Added
### Changed
### Deprecated
### Fixed
### Removed
### Security

---

## References
[datalad]: http://datalad.org
[niceman]: http://niceman.repronim.org
[repronim]: http://repronim.org
[simple_workflow]: https://github.com/ReproNim/simple_workflow
